# frozen_string_literal: true

class OrderLookupsController < ApplicationController
  def create
    error_message = 'No order number or customer number provided'
    @model = if params[:order_number].present?
               error_message = "Order #{params[:order_number]} not found"
               Order.find_or_initialize_by(order_number: params[:order_number])
             elsif params[:customer_number]
               error_message = "No active orders found for #{params[:customer_number]}"
               orders = RxModule::Communicator.call_module_method('rxuniverse_api', 'api/orders/cust', :get, {
                                                                    cust: params[:customer_number]
                                                                  })
               Order.find_or_initialize_by(order_number: orders.first[:orderNumber]) if orders.any?
             end
    if @model.nil?
      render json: { error: error_message }, status: :not_found
    else
      @model.sync_with_rxuniverse!
      if @model.persisted?
        render json: { id: @model.id }
      else
        render json: { error: error_message }, status: :not_found
      end
    end
  end
end