import * as React from 'react';
import { observer } from 'mobx-react-lite';
import FileSaver from "file-saver";
import { downloadTicket } from '../../pages/config/ConfirmationPage';
import {LabMaintenanceStore} from "../../stores/LabMaintenanceStore";
import {useParams} from "react-router-dom";
import {t} from "@lingui/macro";
import {ButtonField} from "@rx-suite/ui";
import printJS from "print-js";
import {OrderModel} from "../../stores/OrderStore";

type Props = {
    mode: "save" | "print",
    order: OrderModel,
    disabled: boolean
}

export const ConfirmationSaveButton: React.FunctionComponent<Props> = observer(({ order, mode = "save", disabled = false }) => {
    const labConfig = LabMaintenanceStore.selectedModel;
    const [loading, setLoading] = React.useState(false);


    const handleClick = React.useCallback(async () => {
        if(!labConfig?.confirmation_template) return;

        setLoading(true);

        const resp = await downloadTicket(order.getId(), "pdf");
        const pdf = await resp.blob();

        if(mode === "save") {
            FileSaver.saveAs(pdf, `order-${order.order_number}.pdf`);
        } else if(mode === "print") {
            const reader = new FileReader();
            const blob = new Blob([pdf], { type: 'application/pdf' });
            reader.readAsDataURL(blob);
            reader.onloadend = () => {
                const base64data = reader.result as string;
                if(base64data) {
                    printJS({printable: base64data.split(",")[1], type: 'pdf', base64: true})
                }

            }
        }
        setLoading(false);
    }, [labConfig?.confirmation_template, order.order_number, mode]);

    const label = mode === "save" ? t`Save` : t`Print`;

    return(
        <ButtonField text={label} loading={loading} disabled={disabled || !labConfig?.confirmation_template} onClick={handleClick}/>
    )
})