import * as React from 'react';
import {LabMaintenanceStore} from "../../stores/LabMaintenanceStore";
import {ModelCheckbox, ModelForm, ModelInput, SerialNumberTable} from "@rx-suite/ui";
import {Box, Divider, Grid, makeStyles, Typography, Container} from "@material-ui/core";
import {Model, stores} from "@rx-suite/data/build";
import {t} from "@lingui/macro";
import {ConfirmationTemplateSelectField} from "../../components/confirmation/ConfirmationTemplateSelectField";

const useStyles = makeStyles({
    bold: {
        fontWeight: 600
    },
    m3: {
        marginTop: 3,
        marginBottom: 3
    },
})

export const LabMaintenanceForm = () => {
    const model = LabMaintenanceStore.selectedModel as Model;
    const classes = useStyles();
    
    return (
        <Grid container spacing={4}>
            <Grid item xs={12}>
                <ModelForm model={model} suppressImportExport>
                    <Box bgcolor='secondary.main' color='white' mt={2} mb={2} p={1}>
                        <Typography variant={'h4'}>{t`Maintain Lab`}</Typography>
                    </Box>
                    <Grid container>
                        <Grid item xs={12}>
                            <ModelInput name={"lab_id"} />
                        </Grid>
                        <Grid item xs={12}>
                            <ModelCheckbox name={"display_addresses"} />
                        </Grid>
                        <Grid item xs={12}>
                            <ModelCheckbox name={"display_wanted_date"} />
                        </Grid>
                        <Grid item xs={12}>
                            <ModelCheckbox name={"display_hold_switch"} />
                        </Grid>
                        <Grid item xs={12}>
                            <ModelCheckbox name={"display_uncut_orders"} />
                        </Grid>
                        <Grid item xs={12}>
                            <ModelCheckbox name={"split_name_on_order_entry"} />
                        </Grid>
                        {/*<Grid item xs={12}>*/}
                        {/*    We'll need this again shortly */}
                        {/*    <ConfirmationTemplateSelectField />*/}
                        {/*</Grid>*/}
                    </Grid>
                    <Divider className={classes.m3}/>
                </ModelForm>
            </Grid>
            <Grid item xs={12}>
                <SerialNumberTable />
            </Grid>
        </Grid>
    );

};
