import * as React from 'react';
import {observer} from 'mobx-react-lite';
import {PerEyeFields} from './PerEyeFields';
import {PerJobFields} from './PerJobFields';
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";
import LoadingOverlay from 'react-loading-overlay';
import {t, Trans} from "@lingui/macro";
import {Box, FormHelperText, LinearProgress, Typography} from "@material-ui/core";
import {useReadonlyContext} from "@rx-suite/ui";

export const GeneratedFields = observer(() => {
    const store = useOrderEntryStore();
    const readOnly = useReadonlyContext();
    const firstFetch = store.fetchingFields && !store.hasFields;
    const error = store.fetchingFieldsError;

    const styleId = store.order?.viewModel.dig("style_id");
    const jobType = store.order?.viewModel.dig("job_type");
    const frameStatus = store.order?.viewModel.dig("_fstatus");

    React.useEffect(() => {
        store.tryFetchFields();
    }, [store, store.order, styleId, jobType, frameStatus])

    if (firstFetch) {
        return (
            <Box display="flex" justifyContent="center" alignItems="center" flexDirection="column">
                <Typography variant="h5"><Trans>Form is loading, please wait...</Trans></Typography>
                <Box width="50%">
                    {error && <FormHelperText error>{error}</FormHelperText>}
                    <LinearProgress/>
                </Box>
            </Box>

        )
    }
    return (
        <>
            {/*// @ts-ignore the types declaration doesn't include children*/}
            <LoadingOverlay
                active={store.fetchingFields && !firstFetch}
                text={t`Fetching fields...`}
                spinner
            >
                {error && !readOnly && <FormHelperText error>{error}</FormHelperText>}
                {store.order?.requiresEyeFields && <PerEyeFields/>}
                {store.order?.requiresJobFields && <PerJobFields/>}
            </LoadingOverlay>
        </>
    )
})
