import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ModelInput} from "@rx-suite/ui";
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";
import {t} from "@lingui/macro";

export const ReleaseNumberInputField: React.FunctionComponent = observer(() => {
    const store = useOrderEntryStore();
    const isVA = store.order?.isVA;
    const disabled = !store.order?.releaseNumRequired

    const label = isVA ? t`Last 4` : t`Release Number`
    const hint = isVA ? {title: t`Last 4`, text: t`The last 4 digits of the Veteran's Social Security number`}
        : {title: t`Release Number`, text: t`The release number used to track third-party billing or safety contracts`}

    return (
        <ModelInput
            name={"release_number"}
            label={label}
            hint={hint}
            disabled={disabled}
        />
    )
})