import {observer} from 'mobx-react-lite';
import * as React from 'react';
import {ButtonField} from "@rx-suite/ui";
import {t, Trans} from "@lingui/macro";
import {moduleIsInstalled} from "@rx-suite/stores";
import {FrameLookupDialog} from "./FrameLookupDialog";
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";
import {FrameFindUPCInput} from "./FrameFindUPCInput";
import {makeStyles, Typography, Grid, Box} from "@material-ui/core";
import {Web} from "@material-ui/icons";

const useStyles = makeStyles(() => ({
    wrapper: {
        width: '100%',
        display: 'flex',
        alignItems: 'baseline'
    },
    scanField: {
        flexGrow: 1
    }
}));

export const FrameLookupButton = observer(() => {
    const store = useOrderEntryStore();
    if (!moduleIsInstalled('rx_inventory') || !store.canPickFrame) {
        return null;
    }

    return(
        <>
            <Grid container spacing={2}>
                <Grid item xs={9}>
                    <FrameFindUPCInput/>
                </Grid>
                <Grid item xs>
                    <Box display={"flex"} alignItems={"center"}>
                        <Typography><Trans>or</Trans></Typography>
                        <ButtonField text={t`Browse Frames`}
                                     onClick={store.showFrameDialog}
                                     startIcon={<Web/>}
                        />
                    </Box>

                </Grid>
            </Grid>
            <FrameLookupDialog/>
        </>

    )
});