import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";
import {Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {useState} from "react";
import {LensPreview} from "./LensPreview";
import { OrderModel } from '../../../stores/OrderStore';

export const FramePreviewButton = observer(() => {
    const model = useModelContext();
    const store = useOrderEntryStore();
    const [open, setOpen] = useState(false);

    const handleClick = React.useCallback(() => {
        store.viewModel.reset()
        setOpen(!open);
    }, [store.viewModel, open]);

    const handleSave = React.useCallback(() => {
        if(!model || !store.viewModel.frameTrace) {
            setOpen(false);
            return;
        }

        (model as OrderModel).setFrameData({
            HBOX: store.viewModel.frameTrace.a,
            VBOX: store.viewModel.frameTrace.b,
            FED: store.viewModel.frameTrace.ed,
            CIRC: store.viewModel.frameTrace.circ,
            DBL: store.viewModel.frameTrace.dbl,
        })

        store.viewModel.submit();
        setOpen(false);
    }, [model, store.viewModel]);

    const disabled = (!model?.viewModel.dig("raw_data.traceID") && !store.viewModel.frameTraceFile) || store.viewModel.frameTrace == null;

    return(
        <>
            <ButtonField text={t`Preview`} disabled={disabled} onClick={handleClick} loading={store.fetchingFrameTrace}/>
            <Dialog open={open} onClose={handleClick} fullWidth maxWidth={"xl"}>
                <DialogTitle>Lens Preview</DialogTitle>
                <DialogContent>
                    <LensPreview />
                </DialogContent>
                <DialogActions>
                    <ButtonField text={t`Save`} onClick={handleSave} />
                    <ButtonField text={t`Close`} onClick={handleClick} />
                </DialogActions>
            </Dialog>
        </>

    )
});