Rails.application.routes.draw do
  mount RxModule::Engine => "/api/rx_module"

  scope :api do
    resources :style_materials
    resources :styles
    resources :style_types
    resources :addons
    resources :shipping_methods
    resources :quick_codes
    resources :customers
    resources :rx_universe, only: :show
    resources :sync_statuses, only: [:index] do
      member do
        post :sync
      end
    end

    resources :order_lookups, only: [:create]
    resources :orders do
      member do
        get "workticket" => "order_workticket#show"
      end
      collection do
        get 'duplicate' => 'orders#duplicate?'
        get 'order_columns' => 'orders#order_columns'
      end
    end


    get "lab_maintenance" => "lab_maintenance#show"
    patch "lab_maintenance/:id" => "lab_maintenance#update"

    get :fields, to: "fields#index"

    get :config_customers, to: "config_customers#index"

    get "configs/summary_columns", to: "configs#selected_summary_columns"
    get :config, to: "configs#index"
    get "config/:id", to: "configs#read"
    patch "config/:id", to: "configs#update", as: :config_update
    post "config/switch_cust", to: "configs#set_last_known_customer"
    namespace :rx_inventory_adapter do
      get "frames" => "frame_lookup#get_frames_by_upc"
      get "frames/:id" => "frame_lookup#get_frame_by_id"

      get "frame_search_options" => "frame_lookup#frame_search_options"
      get "frame_search_options/:id" => "frame_lookup#frame_search_option"
      get "find_frames" => "frame_lookup#find_frames"

      get "frame_traces/:id" => "frame_lookup#trace"
    end

    namespace :maintenance do
      resources :rxuniverse_syncs, only: [:create]
    end
  end

  root "/", controller: :index, action: :show, as: :index_show
  match "*path" => "index#show", :via => :all
end
